<?php declare(strict_types = 1);
/*
** Zabbix
** Copyright (C) 2001-2023 Zabbix SIA
** Copyright (C) 2024 Cybertrust Japan Co., Ltd.
**
** This program is free software: you can redistribute it and/or modify it under the terms of
** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
**
** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
** See the GNU Affero General Public License for more details.
**
** You should have received a copy of the GNU Affero General Public License along with this program.
** If not, see <https://www.gnu.org/licenses/>.
**/


class CControllerSnapshotMembers extends CController {

	protected function init () {
		$this->disableCsrfValidation();
	}

	protected function checkInput(): bool {
		$fields = [
			'snapshotid'	=> 'required|db snapshots.snapshotid',
		];

		$ret = ($this->validateInput($fields));

		if (!$ret) {
			$output = [];

			if (($messages = getMessages()) !== null) {
				$output['errors'] = $messages->toString();
			}

			$this->setResponse(
				(new CControllerResponseData(['main_block' => json_encode($output)]))->disableView()
			);
		}

		return $ret;
	}

	protected function checkPermissions(): bool {
		$snapshots_type = DBfetchArray(DBSelect(
			'select type from snapshots where snapshotid='.
			$this->getInput('snapshotid').
			';'
		));

		switch ($snapshots_type[0]['type']) {
			case ZBX_SNAPSHOT_TYPE_HOST:
			case ZBX_SNAPSHOT_TYPE_TEMPLATE:
				return $this->checkSnapshotAccess();
			default:
				return false;
		}
	}

	protected function doAction(): void {
		$snapshots = DBfetchArray(DBSelect(
			'select type,members from snapshots where snapshotid='.
			$this->getInput('snapshotid').
			';'
		));

		$members = json_decode($snapshots[0]['members'], true);

		switch ($snapshots[0]['type']) {
			case ZBX_SNAPSHOT_TYPE_HOST:
				$title = _('Host list');
				$thead = _n('%1$s host', '%1$s hosts', count($members));
				break;
			case ZBX_SNAPSHOT_TYPE_TEMPLATE:
				$title = _('Template list');
				$thead = _n('%1$s template', '%1$s templates', count($members));
				break;
			default:
				$title = _('Snapshot members');
				$thead = _n('%1$s member', '%1$s members', count($members));
				break;
		}

		$this->setResponse(new CControllerResponseData([
			'title' => $title,
			'thead' => $thead,
			'members' => $members,
			'user' => [
				'debug_mode' => $this->getDebugMode()
			]
		]));
	}
}
