<?php declare(strict_types = 1);
/*
** Zabbix
** Copyright (C) 2001-2023 Zabbix SIA
** Copyright (C) 2024 Cybertrust Japan Co., Ltd.
**
** This program is free software: you can redistribute it and/or modify it under the terms of
** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
**
** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
** See the GNU Affero General Public License for more details.
**
** You should have received a copy of the GNU Affero General Public License along with this program.
** If not, see <https://www.gnu.org/licenses/>.
**/


/**
 * @var CView $this
 * @var array $data
 */

$data['form_name'] = 'snapshot-form';
$popup_url = (new CUrl('zabbix.php'))
	->setArgument('action', 'snapshot.edit')
	->setArgument('snapshotid', $data['snapshotid']);

$buttons = [
	[
		'title' => _('Restore snapshot'),
		'confirmation' => _('Restore from selected snapshot?'),
		'class' => '',
		'keepOpen' => true,
		'isSubmit' => false,
		'action' => 'snapshot_edit_popup.restore('.json_encode($data['snapshotid']).');'
	],
	[
		'title' => _('Update to reflect the change'),
		'class' => 'btn-alt',
		'keepOpen' => true,
		'isSubmit' => true,
		'action' => 'snapshot_edit_popup.submit();'
	],
	[
		'title' => _('Delete'),
		'confirmation' => _('Delete selected snapshot?'),
		'class' => 'btn-alt',
		'keepOpen' => true,
		'isSubmit' => false,
		'action' => 'snapshot_edit_popup.delete('.json_encode($data['snapshotid']).');'
	]
];

$output = [
	'header' => _('Snapshot'),
	'body' => (new CPartial('configuration.snapshot.edit.html', $data))->getOutput(),
	'script_inline' => getPagePostJs().
		$this->readJsFile('popup.snapshot.edit.js.php').
		'snapshot_edit_popup.init('.json_encode([
			'popup_url' => $popup_url->getUrl(),
			'form_name' => $data['form_name']
		]).');',
	'buttons' => $buttons
];

if ($data['user']['debug_mode'] == GROUP_DEBUG_MODE_ENABLED) {
	CProfiler::getInstance()->stop();
	$output['debug'] = CProfiler::getInstance()->make()->toString();
}

echo json_encode($output);
